package edu.mermet.tp8.fenetres;

import edu.mermet.tp8.Application;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.io.*;
import java.util.InvalidPropertiesFormatException;
import java.util.Properties;

public class FenetreConfigurationMenu extends JDialog
{
    private Application owner;
    private Properties properties;

    public FenetreConfigurationMenu(Application owner, String utilisateur)
    {
        super(owner, true);
        this.owner = owner;

        setTitle("Configuration des menus");

        init();

        this.pack();
        this.setLocationRelativeTo(null);
        this.setVisible(true);
    }

    private void init()
    {
        this.properties = new Properties();
        try
        {
            FileInputStream fis = new FileInputStream(new File("./src/main/resources/etatFenetreConfig.xml"));
            this.properties.loadFromXML(fis);
        } catch (Exception e)
        {
            e.printStackTrace();
        }

        JPanel centre = new JPanel();
        centre.setLayout(new BoxLayout(centre, BoxLayout.Y_AXIS));

        String[] applications = new String[]{"Conversion Celsius/Farenheit", "Saisie de texte", "Diaporama", "Boutons"};

        JPanel panel;
        JLabel text;
        ButtonGroup group;
        JRadioButton auto;
        JRadioButton affiche;
        JRadioButton cache;
        for (int i = 0; i < applications.length; i++)
        {
            String appli = applications[i];
            panel = new JPanel(new FlowLayout(FlowLayout.RIGHT));
            text = new JLabel(appli);
            group = new ButtonGroup();
            auto = new JRadioButton(new ActionAuto(appli));
            affiche = new JRadioButton(new ActionVisible(appli));
            cache = new JRadioButton(new ActionCache(appli));

            group.add(auto);
            group.add(affiche);
            group.add(cache);

            String value = properties.getProperty(appli, "Visible");
            System.out.println(value);
            switch (value)
            {
                case "Auto":
                    auto.setSelected(true);
                    break;
                case "Visible":
                    affiche.setSelected(true);
                    break;
                case "Cache":
                    cache.setSelected(true);
            }

            panel.add(text);
            panel.add(auto);
            panel.add(affiche);
            panel.add(cache);

            centre.add(panel);
        }

        JPanel panelBot = new JPanel();
        JButton valider = new JButton("Valider");
        valider.addActionListener(ae -> {
            try
            {
                properties.storeToXML(new FileOutputStream(new File("./src/main/resources/etatFenetreConfig.xml")), null);
            }
            catch (Exception e){}

            dispose();
        });
        panelBot.add(valider);

        this.add(centre, BorderLayout.CENTER);
        this.add(panelBot, BorderLayout.SOUTH);
    }


    public class ActionAuto extends AbstractAction
    {
        private String appliName;

        public ActionAuto(String appliName)
        {
            super("Auto");
            this.appliName = appliName;
        }

        @Override
        public void actionPerformed(ActionEvent e)
        {
            owner.getMenuByName(this.appliName).setVisible(true);
            properties.setProperty(appliName, "Auto");
        }
    }

    public class ActionVisible extends AbstractAction
    {
        private String appliName;

        public ActionVisible(String appliName)
        {
            super("Visible");
            this.appliName = appliName;
        }

        @Override
        public void actionPerformed(ActionEvent e)
        {
            owner.getMenuByName(this.appliName).setVisible(true);
            properties.setProperty(appliName, "Visible");
        }
    }

    public class ActionCache extends AbstractAction
    {
        private String appliName;

        public ActionCache(String appliName)
        {
            super("Caché");
            this.appliName = appliName;
        }

        @Override
        public void actionPerformed(ActionEvent e)
        {
            owner.getMenuByName(this.appliName).setVisible(false);
            properties.setProperty(appliName, "Cache");
        }
    }
}
